<?php
class Audentio_SponsorDirectory_ControllerAdmin_Sponsor extends XenForo_ControllerAdmin_Abstract
{
	protected function _preDispatch($action)
	{
		$this->assertAdminPermission('adsponsordirectory');
	}
	public function actionIndex()
	{
		$sponsorModel = $this->_getSponsorModel();
		$sponsors = $sponsorModel->getAllSponsors();

		$viewParams = array(
			'sponsors'	=> $sponsors,
		);
		return $this->responseView('Audentio_SponsorDirectory_ViewAdmin_Sponsor_List', 'adsponsordirectory_sponsor_list', $viewParams);
	}

	public function actionAdd()
	{
		return $this->responseReroute(__CLASS__, 'edit');
	}

	public function actionEdit()
	{
		$sponsorModel = $this->_getSponsorModel();
		$sponsorId = $this->_input->filterSingle('sponsor_id', XenForo_Input::STRING);

		if ($sponsorId)
		{
			$sponsor = $sponsorModel->getSponsorById($sponsorId);
			if (!$sponsor)
			{
				return $this->responseError(new XenForo_Phrase('adsponsordirectory_this_sponsor_does_not_exist'));
			}
		}
		else
		{
			$sponsor = array(
				'active'			=> 1,
				'display_in_bar'	=> 1,
				'display_on_page'	=> 1,
			);
		}

		$viewParams = array(
			'sponsor'	=> $sponsor,
		);
		return $this->responseView('Audentio_SponsorDirectory_ViewAdmin_Sponsor_Edit', 'adsponsordirectory_sponsor_edit', $viewParams);
	}

	protected function _getUploadImageView(array $sponsor, $modal=false)
	{
		$viewParams = array(
			'sponsor'	=> $sponsor,
			'modal'		=> $modal,
		);

		return $this->responseView('Audentio_SponsorDirectory_ViewAdmin_Sponsor_Upload', 'adsponsordirectory_sponsor_upload', $viewParams);
	}

	public function actionUploadImage()
	{
		$sponsorId = $this->_input->filterSingle('sponsor_id', XenForo_Input::UINT);

		$sponsorModel = $this->_getSponsorModel();

		$sponsor = $sponsorModel->getSponsorById($sponsorId);
		if (!$sponsor)
		{
			return $this->responseError(new XenForo_Phrase('adsponsordirectory_this_sponsor_does_not_exist'));
		}

		return $this->_getUploadImageView($sponsor, true);
	}

	public function actionDoUploadImage()
	{
		$sponsorId = $this->_input->filterSingle('sponsor_id', XenForo_Input::UINT);

		$sponsorModel = $this->_getSponsorModel();
		$sponsor = $sponsorModel->getSponsorById($sponsorId);

		$upload = XenForo_Upload::getUploadedFile('upload_file');
		if (!$upload->isValid())
		{
			throw new XenForo_Exception(new XenForo_Phrase('uploaded_file_is_not_valid_image'), true);
		}
		if (!$upload->isImage())
		{
			throw new XenForo_Exception(new XenForo_Phrase('uploaded_file_is_not_valid_image'), true);
		}
		$imageType = $upload->getImageInfoField('type');
		if (!in_array($imageType, array(IMAGETYPE_GIF, IMAGETYPE_JPEG, IMAGETYPE_PNG)))
		{
			throw new XenForo_Exception(new XenForo_Phrase('uploaded_file_is_not_valid_image'), true);
		}

		if (!is_writable(XenForo_Application::$externalDataPath.'/sponsor/'))
		{
			return $this->responseError(new XenForo_Phrase('adsponsor_sponsor_image_directory_is_not_writable'));
		}
		$fileName = $upload->getTempFile();

		$imageName = XenForo_Application::$time.'-'.$upload->getFileName();

		XenForo_Helper_File::safeRename($fileName, XenForo_Application::$externalDataPath.'/sponsor/'.$imageName);

		if (!empty($ad['extra_data']['uploaded_image_name']) && file_exists(XenForo_Application::$externalDataPath.'/advertisements/'.$ad['extra_data']['uploaded_image_name']))
		{
			@unlink(XenForo_Application::$externalDataPath.'/advertisements/'.$ad['extra_data']['uploaded_image_name']);
		}

		$writer = XenForo_DataWriter::create('Audentio_SponsorDirectory_DataWriter_Sponsor');

		$writer->setExistingData($sponsor['sponsor_id']);
		$writer->set('uploaded_image_name', $imageName);
		$writer->save();

		return $this->responseRedirect(XenForo_ControllerResponse_Redirect::SUCCESS, XenForo_Link::buildAdminLink('sponsordirectory') . $this->getLastHash($sponsor['sponsor_id']));

		/*$fileTransfer = new Zend_File_Transfer_Adapter_Http();
		if ($fileTransfer->isUploaded('upload_file'))
		{
			$fileInfo = $fileTransfer->getFileInfo('upload_file');
			$fileName = $fileInfo['upload_file']['tmp_name'];

			$imageTypes = array(
				'image/jpeg',
				'image/png',
				'image/gif',
			);

			if (!in_array($fileInfo['upload_file']['type'], $imageTypes))
			{
				return $this->responseError(new XenForo_Phrase('adsponsordirectory_invalid_file_type'));
			}

			if (!is_writable('./data/sponsor/'))
			{
				return $this->responseError(new XenForo_Phrase('adsponsor_sponsor_image_directory_is_not_writable'));
			}

			$imageName = XenForo_Application::$time.'-'.$fileInfo['upload_file']['name'];

			XenForo_Helper_File::safeRename($fileName, './data/sponsor/'.$imageName);

			if (!empty($sponsor['uploaded_image_name']) && file_exists('./data/sponsor/'.$sponsor['uploaded_image_name']))
			{
				@unlink('./data/sponsor/'.$sponsor['uploaded_image_name']);
			}

			$writer = XenForo_DataWriter::create('Audentio_SponsorDirectory_DataWriter_Sponsor');

			$writer->setExistingData($sponsor['sponsor_id']);
			$writer->set('uploaded_image_name', $imageName);
			$writer->save();

			return $this->responseRedirect(XenForo_ControllerResponse_Redirect::SUCCESS, XenForo_Link::buildAdminLink('sponsordirectory') . $this->getLastHash($sponsor['sponsor_id']));
		}*/

		return $this->responseError(new XenForo_Phrase('adsponsordirectory_please_choose_an_image_to_upload'));
	}

	public function actionSave()
	{
		$this->_assertPostOnly();

		$sponsorId = $this->_input->filterSingle('sponsor_id', XenForo_Input::UINT);
		$useUploadedImage = $this->_input->filterSingle('use_uploaded_file', XenForo_Input::UINT);

		$writerData = $this->_input->filter(array(
			'title'				=> XenForo_Input::STRING,
			'description'		=> XenForo_Input::STRING,
			'url'				=> XenForo_Input::STRING,
			'use_uploaded_file'	=> XenForo_Input::BOOLEAN,
			'image_url'			=> XenForo_Input::STRING,
			'width'				=> XenForo_Input::UINT,
			'height'			=> XenForo_Input::UINT,
			'active'			=> XenForo_Input::BOOLEAN,
			'display_in_bar'	=> XenForo_Input::BOOLEAN,
			'display_on_page'	=> XenForo_Input::BOOLEAN,
			'display_order'		=> XenForo_Input::UINT,
		));

		$writer = XenForo_DataWriter::create('Audentio_SponsorDirectory_DataWriter_Sponsor');
		$writer->bulkSet($writerData);
		if ($sponsorId)
		{
			$writer->setExistingData($sponsorId);
		}
		$writer->save();

		$sponsor = $writer->getMergedData();

		if ($useUploadedImage)
		{
			$fileExists = false;
			if (!empty($sponsor['uploaded_image_name']) && file_exists('./data/sponsor/'.$sponsor['uploaded_image_name']))
			{
				$fileExists = true;
			}
			if (!$fileExists)
			{
				return $this->responseRedirect(XenForo_ControllerResponse_Redirect::SUCCESS, XenForo_Link::buildAdminLink('sponsordirectory/upload-image', $sponsor));
				//return $this->_getUploadImageView($sponsor);
			}
		}

		return $this->responseRedirect(
			XenForo_ControllerResponse_Redirect::SUCCESS,
			XenForo_Link::buildAdminLink('sponsordirectory') . $this->getLastHash($writer->get('sponsor_id'))
		);
	}

	public function actionDelete()
	{
		$sponsorId = $this->_input->filterSingle('sponsor_id', XenForo_Input::UINT);
		$writer = XenForo_DataWriter::create('Audentio_SponsorDirectory_DataWriter_Sponsor');
		$writer->setExistingData($sponsorId);
		$writer->delete();

		return $this->responseRedirect(
			XenForo_ControllerResponse_Redirect::SUCCESS,
			XenForo_Link::buildAdminLink('sponsordirectory')
		);
	}

	public function actionToggle()
	{
		return $this->_getToggleResponse(
			$this->_getSponsorModel()->getAllSponsors(),
			'Audentio_SponsorDirectory_DataWriter_Sponsor',
			'sponsordirectory');
	}

	protected function _getSponsorModel()
	{
		return $this->getModelFromCache('Audentio_SponsorDirectory_Model_Sponsor');
	}
}